Logging utilities for pr_comments.
Provides a helper context that reduces duplication when logging tool calls to the thoughts logs directory using agentic_logging.
Structs
- Tool
LogCtx - Context for logging a single tool call.
Logging utilities for pr_comments.
Provides a helper context that reduces duplication when logging tool calls to the thoughts logs directory using agentic_logging.